<?php

namespace Ardent\Undercurrent\Http;

use Ardent\Undercurrent\Container\ClassNotFoundException;
use Ardent\Undercurrent\Container\ContainerInterface;

class GenericRouter implements RouterInterface
{
    public function __construct(
        private readonly ContainerInterface $container,
        private readonly RouterConfig       $config,
    )
    {
    }

    /**
     * @throws RouteNotFoundException|ClassNotFoundException
     */
    public function dispatch(RequestInterface $request): ResponseInterface
    {
        foreach ($this->config->getRoutes() as $route) {
            if ($route->getRoute()->path === $request->getUri()) {
                $controller = $this->container->get($route->getController());
                $method = $route->getMethod();
                return $controller->$method();
            }
        }

        throw new RouteNotFoundException($request);
    }
}